pub struct MonitorEvent {
pub sequence: u64,
pub monitor_id: String,
pub message: String,
pub queue_turn_input: Option<String>,
}Fields
sequence: u64monitor_id: Stringmessage: Stringqueue_turn_input: Option<String>Trait Implementations
Sourceimpl Clone for MonitorEvent
impl Clone for MonitorEvent
Sourcefn clone(&self) -> MonitorEvent
fn clone(&self) -> MonitorEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorEvent
impl Debug for MonitorEvent
Sourceimpl Default for MonitorEvent
impl Default for MonitorEvent
Sourcefn default() -> MonitorEvent
fn default() -> MonitorEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MonitorEvent
impl<'de> Deserialize<'de> for MonitorEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorEvent
impl JsonSchema for MonitorEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MonitorEvent
impl PartialEq for MonitorEvent
Sourcefn eq(&self, other: &MonitorEvent) -> bool
fn eq(&self, other: &MonitorEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MonitorEvent
impl Serialize for MonitorEvent
impl Eq for MonitorEvent
impl StructuralPartialEq for MonitorEvent