pub struct MonitorSnapshot {
pub revision: u64,
pub active_count: usize,
pub monitors: Vec<MonitorStatus>,
}Fields
revision: u64active_count: usizemonitors: Vec<MonitorStatus>Trait Implementations
Sourceimpl Clone for MonitorSnapshot
impl Clone for MonitorSnapshot
Sourcefn clone(&self) -> MonitorSnapshot
fn clone(&self) -> MonitorSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorSnapshot
impl Debug for MonitorSnapshot
Sourceimpl Default for MonitorSnapshot
impl Default for MonitorSnapshot
Sourcefn default() -> MonitorSnapshot
fn default() -> MonitorSnapshot
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MonitorSnapshot
impl<'de> Deserialize<'de> for MonitorSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorSnapshot
impl JsonSchema for MonitorSnapshot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MonitorSnapshot
impl PartialEq for MonitorSnapshot
Sourcefn eq(&self, other: &MonitorSnapshot) -> bool
fn eq(&self, other: &MonitorSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MonitorSnapshot
impl Serialize for MonitorSnapshot
impl Eq for MonitorSnapshot
impl StructuralPartialEq for MonitorSnapshot