pub struct MonitorSpec {
pub id: String,
pub command: String,
pub cwd: Option<String>,
pub env: BTreeMap<String, String>,
pub persistent: bool,
pub timeout_ms: u64,
pub arm_on: MonitorArmOn,
pub wake_policy: MonitorWakePolicy,
pub restart_on_restore: bool,
}Fields
id: Stringcommand: Stringcwd: Option<String>env: BTreeMap<String, String>persistent: booltimeout_ms: u64arm_on: MonitorArmOnwake_policy: MonitorWakePolicyrestart_on_restore: boolTrait Implementations
Sourceimpl Clone for MonitorSpec
impl Clone for MonitorSpec
Sourcefn clone(&self) -> MonitorSpec
fn clone(&self) -> MonitorSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorSpec
impl Debug for MonitorSpec
Sourceimpl Default for MonitorSpec
impl Default for MonitorSpec
Sourcefn default() -> MonitorSpec
fn default() -> MonitorSpec
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MonitorSpec
impl<'de> Deserialize<'de> for MonitorSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorSpec
impl JsonSchema for MonitorSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MonitorSpec
impl PartialEq for MonitorSpec
Sourcefn eq(&self, other: &MonitorSpec) -> bool
fn eq(&self, other: &MonitorSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MonitorSpec
impl Serialize for MonitorSpec
impl Eq for MonitorSpec
impl StructuralPartialEq for MonitorSpec