pub struct MonitorUpdateBatch {
pub revision: u64,
pub active_count: usize,
pub events: Vec<MonitorEvent>,
}Fields
revision: u64active_count: usizeevents: Vec<MonitorEvent>Trait Implementations
Sourceimpl Clone for MonitorUpdateBatch
impl Clone for MonitorUpdateBatch
Sourcefn clone(&self) -> MonitorUpdateBatch
fn clone(&self) -> MonitorUpdateBatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorUpdateBatch
impl Debug for MonitorUpdateBatch
Sourceimpl Default for MonitorUpdateBatch
impl Default for MonitorUpdateBatch
Sourcefn default() -> MonitorUpdateBatch
fn default() -> MonitorUpdateBatch
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MonitorUpdateBatch
impl<'de> Deserialize<'de> for MonitorUpdateBatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorUpdateBatch
impl JsonSchema for MonitorUpdateBatch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MonitorUpdateBatch
impl PartialEq for MonitorUpdateBatch
Sourcefn eq(&self, other: &MonitorUpdateBatch) -> bool
fn eq(&self, other: &MonitorUpdateBatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MonitorUpdateBatch
impl Serialize for MonitorUpdateBatch
impl Eq for MonitorUpdateBatch
impl StructuralPartialEq for MonitorUpdateBatch