SessionLifecycleHost

Trait SessionLifecycleHost 

pub trait SessionLifecycleHost: Send + Sync {
    // Required methods
    fn create_session<'life0, 'async_trait>(
        &'life0 self,
        request: SessionCreateRequest,
    ) -> Pin<Box<dyn Future<Output = Result<SessionHandle, PluginError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn close_session<'life0, 'life1, 'async_trait>(
        &'life0 self,
        session_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<(), PluginError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;

    // Provided method
    fn take_first_turn_input<'life0, 'life1, 'async_trait>(
        &'life0 self,
        _session_id: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Option<PluginMessage>, PluginError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}

Required Methods

fn create_session<'life0, 'async_trait>( &'life0 self, request: SessionCreateRequest, ) -> Pin<Box<dyn Future<Output = Result<SessionHandle, PluginError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn close_session<'life0, 'life1, 'async_trait>( &'life0 self, session_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<(), PluginError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Provided Methods

fn take_first_turn_input<'life0, 'life1, 'async_trait>( &'life0 self, _session_id: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Option<PluginMessage>, PluginError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Pop the seed message that was queued for session_id via SessionCreateRequest::first_turn_input. Returns None if no seed was queued, or after a previous caller has already taken it. Hosts call this when starting the inaugural turn on a freshly created session.

Implementors