pub struct AckWakeArgs {
pub ids: Vec<String>,
}Fields
ids: Vec<String>Trait Implementations
Sourceimpl Clone for AckWakeArgs
impl Clone for AckWakeArgs
Sourcefn clone(&self) -> AckWakeArgs
fn clone(&self) -> AckWakeArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AckWakeArgs
impl Debug for AckWakeArgs
Sourceimpl Default for AckWakeArgs
impl Default for AckWakeArgs
Sourcefn default() -> AckWakeArgs
fn default() -> AckWakeArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AckWakeArgs
impl<'de> Deserialize<'de> for AckWakeArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AckWakeArgs
impl JsonSchema for AckWakeArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AckWakeArgs
impl RefUnwindSafe for AckWakeArgs
impl Send for AckWakeArgs
impl Sync for AckWakeArgs
impl Unpin for AckWakeArgs
impl UnsafeUnpin for AckWakeArgs
impl UnwindSafe for AckWakeArgs