pub struct MonitorEmptyArgs {}Trait Implementations
Sourceimpl Clone for MonitorEmptyArgs
impl Clone for MonitorEmptyArgs
Sourcefn clone(&self) -> MonitorEmptyArgs
fn clone(&self) -> MonitorEmptyArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorEmptyArgs
impl Debug for MonitorEmptyArgs
Sourceimpl Default for MonitorEmptyArgs
impl Default for MonitorEmptyArgs
Sourcefn default() -> MonitorEmptyArgs
fn default() -> MonitorEmptyArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MonitorEmptyArgs
impl<'de> Deserialize<'de> for MonitorEmptyArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorEmptyArgs
impl JsonSchema for MonitorEmptyArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MonitorEmptyArgs
impl RefUnwindSafe for MonitorEmptyArgs
impl Send for MonitorEmptyArgs
impl Sync for MonitorEmptyArgs
impl Unpin for MonitorEmptyArgs
impl UnsafeUnpin for MonitorEmptyArgs
impl UnwindSafe for MonitorEmptyArgs