pub struct OwnedMonitorSpec {
pub plugin_id: Option<String>,
pub spec: MonitorSpec,
}Fields
plugin_id: Option<String>spec: MonitorSpecTrait Implementations
Sourceimpl Clone for OwnedMonitorSpec
impl Clone for OwnedMonitorSpec
Sourcefn clone(&self) -> OwnedMonitorSpec
fn clone(&self) -> OwnedMonitorSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OwnedMonitorSpec
impl Debug for OwnedMonitorSpec
Sourceimpl<'de> Deserialize<'de> for OwnedMonitorSpec
impl<'de> Deserialize<'de> for OwnedMonitorSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OwnedMonitorSpec
impl JsonSchema for OwnedMonitorSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OwnedMonitorSpec
impl RefUnwindSafe for OwnedMonitorSpec
impl Send for OwnedMonitorSpec
impl Sync for OwnedMonitorSpec
impl Unpin for OwnedMonitorSpec
impl UnsafeUnpin for OwnedMonitorSpec
impl UnwindSafe for OwnedMonitorSpec