pub struct RegisterSpecsArgs {
pub specs: Vec<OwnedMonitorSpec>,
}Fields
specs: Vec<OwnedMonitorSpec>Trait Implementations
Sourceimpl Clone for RegisterSpecsArgs
impl Clone for RegisterSpecsArgs
Sourcefn clone(&self) -> RegisterSpecsArgs
fn clone(&self) -> RegisterSpecsArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterSpecsArgs
impl Debug for RegisterSpecsArgs
Sourceimpl Default for RegisterSpecsArgs
impl Default for RegisterSpecsArgs
Sourcefn default() -> RegisterSpecsArgs
fn default() -> RegisterSpecsArgs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RegisterSpecsArgs
impl<'de> Deserialize<'de> for RegisterSpecsArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RegisterSpecsArgs
impl JsonSchema for RegisterSpecsArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RegisterSpecsArgs
impl RefUnwindSafe for RegisterSpecsArgs
impl Send for RegisterSpecsArgs
impl Sync for RegisterSpecsArgs
impl Unpin for RegisterSpecsArgs
impl UnsafeUnpin for RegisterSpecsArgs
impl UnwindSafe for RegisterSpecsArgs