pub struct StartMonitorArgs {
pub spec: MonitorSpec,
}Fields
spec: MonitorSpecTrait Implementations
Sourceimpl Clone for StartMonitorArgs
impl Clone for StartMonitorArgs
Sourcefn clone(&self) -> StartMonitorArgs
fn clone(&self) -> StartMonitorArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartMonitorArgs
impl Debug for StartMonitorArgs
Sourceimpl<'de> Deserialize<'de> for StartMonitorArgs
impl<'de> Deserialize<'de> for StartMonitorArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StartMonitorArgs
impl JsonSchema for StartMonitorArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StartMonitorArgs
impl RefUnwindSafe for StartMonitorArgs
impl Send for StartMonitorArgs
impl Sync for StartMonitorArgs
impl Unpin for StartMonitorArgs
impl UnsafeUnpin for StartMonitorArgs
impl UnwindSafe for StartMonitorArgs