pub struct StopMonitorArgs {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Clone for StopMonitorArgs
impl Clone for StopMonitorArgs
Sourcefn clone(&self) -> StopMonitorArgs
fn clone(&self) -> StopMonitorArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StopMonitorArgs
impl Debug for StopMonitorArgs
Sourceimpl<'de> Deserialize<'de> for StopMonitorArgs
impl<'de> Deserialize<'de> for StopMonitorArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StopMonitorArgs
impl JsonSchema for StopMonitorArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StopMonitorArgs
impl RefUnwindSafe for StopMonitorArgs
impl Send for StopMonitorArgs
impl Sync for StopMonitorArgs
impl Unpin for StopMonitorArgs
impl UnsafeUnpin for StopMonitorArgs
impl UnwindSafe for StopMonitorArgs