pub struct AgentModelSelection {
pub model: String,
pub variant: Option<String>,
}Expand description
Model + optional variant returned by provider model policies for agent tiers.
Fields
model: Stringvariant: Option<String>Trait Implementations
Sourceimpl Clone for AgentModelSelection
impl Clone for AgentModelSelection
Sourcefn clone(&self) -> AgentModelSelection
fn clone(&self) -> AgentModelSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentModelSelection
impl Debug for AgentModelSelection
Sourceimpl PartialEq for AgentModelSelection
impl PartialEq for AgentModelSelection
Sourcefn eq(&self, other: &AgentModelSelection) -> bool
fn eq(&self, other: &AgentModelSelection) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for AgentModelSelection
impl StructuralPartialEq for AgentModelSelection