pub enum EffectScope {
Turn {
session_id: String,
turn_id: String,
},
Process {
process_id: String,
},
QueueDrain {
session_id: String,
drain_id: String,
},
SessionDelete {
session_id: String,
},
RuntimeOperation {
operation_id: String,
},
}Expand description
Stable semantic identity for one effectful runtime operation.
The scope is chosen by the host boundary before any nondeterministic work is planned. It is intentionally generic: Restate, an inline test host, or a future durable effect host all receive the same Lash scope vocabulary.
Variants
Implementations
Sourceimpl EffectScope
impl EffectScope
pub fn turn(session_id: impl Into<String>, turn_id: impl Into<String>) -> Self
pub fn process(process_id: impl Into<String>) -> Self
pub fn queue_drain( session_id: impl Into<String>, drain_id: impl Into<String>, ) -> Self
pub fn session_delete(session_id: impl Into<String>) -> Self
pub fn runtime_operation(operation_id: impl Into<String>) -> Self
pub fn id(&self) -> &str
pub fn session_id(&self) -> Option<&str>
pub fn turn_id(&self) -> Option<&str>
pub fn validates_turn_trace_id(&self) -> bool