pub struct AgentFrameRun {
pub turns: Vec<AssembledTurn>,
}Expand description
Result of driving one logical host turn through any AgentFrame switches.
A frame switch is an internal runtime continuation, similar to compaction
from a host’s perspective. Callers that need a final answer can use
LashRuntime::stream_turn_with_agent_frames and inspect final_turn().
Fields
turns: Vec<AssembledTurn>Implementations
Sourceimpl AgentFrameRun
impl AgentFrameRun
pub fn final_turn(&self) -> Option<&AssembledTurn>
pub fn into_final_turn(self) -> Option<AssembledTurn>
pub fn frame_switch_count(&self) -> usize