EmbeddedRuntimeBuilder

Struct EmbeddedRuntimeBuilder 

pub struct EmbeddedRuntimeBuilder { /* private fields */ }

Implementations

Source

impl EmbeddedRuntimeBuilder

pub fn new() -> Self

pub fn session_id(&self) -> Option<&str>

pub fn policy(&self) -> Option<&SessionPolicy>

pub fn with_session_id(self, session_id: impl Into<String>) -> Self

pub fn with_policy(self, policy: SessionPolicy) -> Self

pub fn with_initial_state(self, state: RuntimeSessionState) -> Self

pub fn with_plugin_host(self, plugin_host: PluginHost) -> Self

pub fn with_plugin_session(self, plugin_session: Arc<PluginSession>) -> Self

pub fn with_plugin_factories( self, factories: Vec<Arc<dyn PluginFactory>>, ) -> Self

pub fn with_plugin_stack(self, stack: PluginStack) -> Self

pub fn with_runtime_host(self, core: RuntimeHostConfig) -> Self

pub fn with_attachment_store( self, attachment_store: Arc<dyn AttachmentStore>, ) -> Self

pub fn with_prompt_template(self, prompt_template: PromptTemplate) -> Self

pub fn with_prompt_contribution(self, contribution: PromptContribution) -> Self

pub fn with_replaced_prompt_slot( self, slot: PromptSlot, contributions: impl IntoIterator<Item = PromptContribution>, ) -> Self

pub fn with_cleared_prompt_slot(self, slot: PromptSlot) -> Self

pub fn with_prompt_layer(self, prompt: PromptLayer) -> Self

pub fn with_trace_sink(self, sink: Option<Arc<dyn TraceSink>>) -> Self

pub fn with_lashlang_execution_sink( self, sink: Option<Arc<dyn TraceSink>>, ) -> Self

pub fn with_lashlang_execution_jsonl_path(self, path: Option<PathBuf>) -> Self

pub fn with_trace_level(self, level: TraceLevel) -> Self

pub fn with_trace_context(self, context: TraceContext) -> Self

pub fn with_termination(self, termination: TerminationPolicy) -> Self

pub fn with_effect_host(self, effect_host: Arc<dyn EffectHost>) -> Self

pub fn with_provider_resolver( self, provider_resolver: Arc<dyn RuntimeProviderResolver>, ) -> Self

pub fn with_session_store_factory( self, session_store_factory: Arc<dyn SessionStoreFactory>, ) -> Self

pub fn with_host_event_store(self, store: Arc<dyn HostEventStore>) -> Self

pub fn with_store(self, store: Arc<dyn RuntimePersistence>) -> Self

pub fn with_process_registry( self, process_registry: Arc<dyn ProcessRegistry>, ) -> Self

pub fn with_residency(self, residency: Residency) -> Self

Trim a rebuilt session’s resident graph to match the host’s residency.

Defaults to Residency::KeepAll. Setting Residency::ActivePathOnly makes a rebuilt runtime (e.g. a durable worker reconstructing a session to run a background process) keep only the active path resident, matching the live runtime’s behavior instead of silently retaining the full graph.

pub async fn build(self) -> Result<LashRuntime, SessionError>

pub async fn build_ephemeral(self) -> Result<LashRuntime, SessionError>

pub async fn build_persistent( self, store: Arc<dyn RuntimePersistence>, ) -> Result<LashRuntime, SessionError>

pub async fn build_background_persistent( self, store: Arc<dyn RuntimePersistence>, process_registry: Arc<dyn ProcessRegistry>, ) -> Result<LashRuntime, SessionError>