pub struct FollowedTurn {
pub turns: Vec<AssembledTurn>,
}Expand description
Result of driving one logical host turn through any foreground handoffs.
A handoff is an internal runtime continuation, similar to compaction from a
host’s perspective. Callers that need a final answer can use
LashRuntime::stream_turn_following_handoffs and inspect final_turn().
Fields
turns: Vec<AssembledTurn>Implementations
Sourceimpl FollowedTurn
impl FollowedTurn
pub fn final_turn(&self) -> Option<&AssembledTurn>
pub fn into_final_turn(self) -> Option<AssembledTurn>
pub fn handoff_count(&self) -> usize