pub struct LlmAttachmentSpec {
pub reference: AttachmentRef,
}Expand description
Serializable attachment data for runtime effect envelopes.
Effect envelopes carry attachment references only. Local executors resolve bytes from the configured attachment store when a provider request is actually executed.
Fields
reference: AttachmentRefTrait Implementations
Sourceimpl Clone for LlmAttachmentSpec
impl Clone for LlmAttachmentSpec
Sourcefn clone(&self) -> LlmAttachmentSpec
fn clone(&self) -> LlmAttachmentSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LlmAttachmentSpec
impl Debug for LlmAttachmentSpec
Sourceimpl<'de> Deserialize<'de> for LlmAttachmentSpec
impl<'de> Deserialize<'de> for LlmAttachmentSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LlmAttachmentSpec
Sourceimpl PartialEq for LlmAttachmentSpec
impl PartialEq for LlmAttachmentSpec
Sourcefn eq(&self, other: &LlmAttachmentSpec) -> bool
fn eq(&self, other: &LlmAttachmentSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LlmAttachmentSpec
impl Serialize for LlmAttachmentSpec
impl StructuralPartialEq for LlmAttachmentSpec