pub struct PersistedSegmentHandover {
pub segment_ordinal: u64,
pub program_hash: String,
pub handover: SegmentHandover,
}Expand description
The single bounded continuation durably retained for a process incarnation.
This is registry-internal execution state: it is deliberately not a process event and therefore never appears in change feeds or provenance.
Fields
segment_ordinal: u64program_hash: Stringhandover: SegmentHandoverTrait Implementations
Sourceimpl Clone for PersistedSegmentHandover
impl Clone for PersistedSegmentHandover
Sourcefn clone(&self) -> PersistedSegmentHandover
fn clone(&self) -> PersistedSegmentHandover
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersistedSegmentHandover
impl Debug for PersistedSegmentHandover
Sourceimpl<'de> Deserialize<'de> for PersistedSegmentHandover
impl<'de> Deserialize<'de> for PersistedSegmentHandover
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PersistedSegmentHandover
Sourceimpl PartialEq for PersistedSegmentHandover
impl PartialEq for PersistedSegmentHandover
Sourceimpl Serialize for PersistedSegmentHandover
impl Serialize for PersistedSegmentHandover
impl StructuralPartialEq for PersistedSegmentHandover