pub struct ProcessExternalRef {
pub backend: String,
pub id: String,
pub metadata: Option<Value>,
}Expand description
Durable backend reference for background work accepted outside the local process.
Fields
backend: Stringid: Stringmetadata: Option<Value>Trait Implementations
Sourceimpl Clone for ProcessExternalRef
impl Clone for ProcessExternalRef
Sourcefn clone(&self) -> ProcessExternalRef
fn clone(&self) -> ProcessExternalRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessExternalRef
impl Debug for ProcessExternalRef
Sourceimpl Default for ProcessExternalRef
impl Default for ProcessExternalRef
Sourcefn default() -> ProcessExternalRef
fn default() -> ProcessExternalRef
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProcessExternalRef
impl<'de> Deserialize<'de> for ProcessExternalRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProcessExternalRef
impl PartialEq for ProcessExternalRef
Sourcefn eq(&self, other: &ProcessExternalRef) -> bool
fn eq(&self, other: &ProcessExternalRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessExternalRef
impl Serialize for ProcessExternalRef
impl StructuralPartialEq for ProcessExternalRef