pub struct ProcessSpawnProvenance {
pub originator: ProcessOriginator,
pub wake_target: Option<SessionScope>,
}Expand description
Provenance a process-run context hands to its children: the chain’s originator and the chain’s wake target. Mirrors the trigger fire path, where the spawned process inherits the registrant and the grant is derived from the wake target.
Fields
originator: ProcessOriginatorwake_target: Option<SessionScope>Trait Implementations
Sourceimpl Clone for ProcessSpawnProvenance
impl Clone for ProcessSpawnProvenance
Sourcefn clone(&self) -> ProcessSpawnProvenance
fn clone(&self) -> ProcessSpawnProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessSpawnProvenance
impl Debug for ProcessSpawnProvenance
impl Eq for ProcessSpawnProvenance
Sourceimpl PartialEq for ProcessSpawnProvenance
impl PartialEq for ProcessSpawnProvenance
Sourcefn eq(&self, other: &ProcessSpawnProvenance) -> bool
fn eq(&self, other: &ProcessSpawnProvenance) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProcessSpawnProvenance