pub struct RuntimeError {
pub code: RuntimeErrorCode,
pub message: String,
}Expand description
Runtime error for unexpected failures.
Fields
code: RuntimeErrorCodemessage: StringImplementations
Sourceimpl RuntimeError
impl RuntimeError
pub fn new( code: impl Into<RuntimeErrorCode>, message: impl Into<String>, ) -> Self
pub fn is_code(&self, code: RuntimeErrorCode) -> bool
Sourcepub fn durable_store_required(facet: DurableStoreFacet) -> Self
pub fn durable_store_required(facet: DurableStoreFacet) -> Self
Build the loud error raised when a durable execution path was wired
against an ephemeral store for facet.
Sourcepub fn missing_process_execution_id() -> Self
pub fn missing_process_execution_id() -> Self
Build the loud error raised when a process (re-)execution is handed an empty/non-persisted id.
Process execution identity is the persisted process_id, so a retry
must present that stable id — mirroring how
EffectScope rejects an empty stable id.