ToolDefinition

Struct ToolDefinition 

pub struct ToolDefinition {
Show 14 fields pub name: String, pub description: String, pub input_schema: Value, pub output_schema: Value, pub input_schema_projections: Vec<SchemaProjectionOverride>, pub output_schema_projections: Vec<SchemaProjectionOverride>, pub output_contract: ToolOutputContract, pub examples: Vec<String>, pub availability: ToolAvailabilityConfig, pub activation: ToolActivation, pub availability_override: Option<ToolAvailability>, pub discovery: ToolDiscoveryMetadata, pub execution_mode: ToolExecutionMode, pub retry_policy: ToolRetryPolicy,
}
Static authoring helper for tools.

Fields

name: Stringdescription: Stringinput_schema: Valueoutput_schema: Valueinput_schema_projections: Vec<SchemaProjectionOverride>output_schema_projections: Vec<SchemaProjectionOverride>output_contract: ToolOutputContractexamples: Vec<String>availability: ToolAvailabilityConfigactivation: ToolActivationavailability_override: Option<ToolAvailability>discovery: ToolDiscoveryMetadataexecution_mode: ToolExecutionMode

How this tool should be scheduled relative to peers when the model emits a batch of tool calls. Defaults to ToolExecutionMode::Parallel.

retry_policy: ToolRetryPolicy

Whether this tool may be retried automatically after a failure that explicitly opts into safe retry.

Implementations

Source

impl ToolDefinition

pub fn raw( name: impl Into<String>, description: impl Into<String>, input_schema: Value, output_schema: Value, ) -> ToolDefinition

pub fn typed<Args, Output>( name: impl Into<String>, description: impl Into<String>, ) -> ToolDefinition
where Args: JsonSchema, Output: JsonSchema,

pub fn with_examples(self, examples: Vec<String>) -> ToolDefinition

pub fn with_availability( self, availability: ToolAvailabilityConfig, ) -> ToolDefinition

pub fn with_activation(self, activation: ToolActivation) -> ToolDefinition

pub fn with_discovery(self, discovery: ToolDiscoveryMetadata) -> ToolDefinition

pub fn with_execution_mode( self, execution_mode: ToolExecutionMode, ) -> ToolDefinition

pub fn with_retry_policy(self, retry_policy: ToolRetryPolicy) -> ToolDefinition

pub fn with_output_contract( self, output_contract: ToolOutputContract, ) -> ToolDefinition

pub fn with_input_schema_projection( self, profile: impl Into<String>, schema: Value, ) -> ToolDefinition

pub fn with_output_schema_projection( self, profile: impl Into<String>, schema: Value, ) -> ToolDefinition

pub fn with_output_from_input_schema( self, input_field: impl Into<String>, default_schema: Option<Value>, ) -> ToolDefinition

pub fn default_input_schema() -> Value

pub fn input_signature(&self) -> String

pub fn output_summary(&self) -> String

pub fn signature(&self) -> String

pub fn compact_contract(&self) -> CompactToolContract

pub fn compact_contract_with_example_limit( &self, example_limit: usize, ) -> CompactToolContract

pub fn effective_availability(&self, mode: &ExecutionMode) -> ToolAvailability

pub fn model_tool(&self) -> ModelTool

pub fn manifest(&self) -> ToolManifest

pub fn contract(&self) -> ToolContract

pub fn from_manifest_and_contract( manifest: ToolManifest, contract: ToolContract, ) -> ToolDefinition

pub fn format_tool_docs(tools: &[ToolDefinition]) -> String

pub fn format_tool_docs_iter<'a>( tools: impl IntoIterator<Item = &'a ToolDefinition>, ) -> String

pub fn parameter_metadata(&self) -> Vec<Value>