pub struct TraceLashlangGraphChildLink {
pub parent_graph_key: String,
pub parent_node_id: String,
pub child_graph_key: String,
pub child_module_ref: Option<String>,
pub child_entry_ref: Option<String>,
pub child_entry_name: Option<String>,
}Expand description
Link from an observed parent Lashlang node to a child execution graph.
Fields
parent_graph_key: Stringparent_node_id: Stringchild_graph_key: Stringchild_module_ref: Option<String>child_entry_ref: Option<String>child_entry_name: Option<String>Trait Implementations
Sourceimpl Clone for TraceLashlangGraphChildLink
impl Clone for TraceLashlangGraphChildLink
Sourcefn clone(&self) -> TraceLashlangGraphChildLink
fn clone(&self) -> TraceLashlangGraphChildLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceLashlangGraphChildLink
impl Debug for TraceLashlangGraphChildLink
Sourceimpl<'de> Deserialize<'de> for TraceLashlangGraphChildLink
impl<'de> Deserialize<'de> for TraceLashlangGraphChildLink
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceLashlangGraphChildLink, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TraceLashlangGraphChildLink, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TraceLashlangGraphChildLink
Sourceimpl PartialEq for TraceLashlangGraphChildLink
impl PartialEq for TraceLashlangGraphChildLink
Sourcefn eq(&self, other: &TraceLashlangGraphChildLink) -> bool
fn eq(&self, other: &TraceLashlangGraphChildLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TraceLashlangGraphChildLink
impl Serialize for TraceLashlangGraphChildLink
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TraceLashlangGraphChildLink