pub struct TraceLashlangGraphStore { /* private fields */ }Expand description
In-memory store that reduces Lashlang execution trace records into graph snapshots.
Implementations
Sourceimpl TraceLashlangGraphStore
impl TraceLashlangGraphStore
Sourcepub fn graph(&self, graph_key: &str) -> Option<TraceLashlangGraph>
pub fn graph(&self, graph_key: &str) -> Option<TraceLashlangGraph>
Returns a snapshot for one observed Lashlang graph key.
Sourcepub fn graphs(&self) -> Vec<TraceLashlangGraph>
pub fn graphs(&self) -> Vec<TraceLashlangGraph>
Returns snapshots for all observed executions in stable graph-key order.