pub enum ToolRetryPolicy {
Never,
Safe {
max_attempts: u32,
base_delay_ms: u64,
max_delay_ms: u64,
},
Idempotent {
max_attempts: u32,
base_delay_ms: u64,
max_delay_ms: u64,
},
}Expand description
Automatic retry policy for a tool’s execution.
This is intentionally separate from ToolScheduling: scheduling
decides whether different tool calls may run together, while retry policy
decides whether one failed call may be attempted again inside its scheduled
slot.
Variants
Never
Never retry automatically. This is the default for every tool.
Safe
Retry only failures that explicitly report a safe retry disposition.
Idempotent
Retry only failures that explicitly report a safe retry disposition, and only when the runtime can provide a stable replay key.
Implementations
Sourceimpl ToolRetryPolicy
impl ToolRetryPolicy
pub fn safe( max_attempts: u32, base_delay_ms: u64, max_delay_ms: u64, ) -> ToolRetryPolicy
pub fn idempotent( max_attempts: u32, base_delay_ms: u64, max_delay_ms: u64, ) -> ToolRetryPolicy
pub fn max_attempts(self) -> u32
pub fn delay_ms_for_retry( self, retry_index: u32, requested_after_ms: Option<u64>, ) -> u64
pub fn requires_replay_key(self) -> bool