pub struct ModelSpec {
pub id: String,
pub variant: Option<String>,
pub limits: ModelLimits,
}Fields
id: Stringvariant: Option<String>limits: ModelLimitsImplementations
Sourceimpl ModelSpec
impl ModelSpec
pub fn new(id: impl Into<String>, context_window_tokens: NonZeroUsize) -> Self
pub fn with_limits( id: impl Into<String>, variant: Option<String>, limits: ModelLimits, ) -> Self
pub fn with_variant(self, variant: Option<String>) -> Self
Sourcepub fn from_token_limits(
id: impl Into<String>,
variant: Option<String>,
context_window_tokens: usize,
output_token_capacity: Option<usize>,
) -> Result<Self, String>
pub fn from_token_limits( id: impl Into<String>, variant: Option<String>, context_window_tokens: usize, output_token_capacity: Option<usize>, ) -> Result<Self, String>
Build a spec from the prompt budget (context_window_tokens — the
maximum input the provider accepts for this model on this route) and the
optional output cap. The budget is what history pruning and the UI
measure against.
pub fn context_window_tokens(&self) -> usize